@@ -1,7 +1,7 @@
 /*
    Some physical constants.
 
-   Copyright (C) 2004, 2005, 2009 Oleksandr Yermolenko
+   Copyright (C) 2004, 2005, 2009, 2012 Oleksandr Yermolenko
    <oleksandr.yermolenko@gmail.com>
 
    This file is part of MDTK, the Molecular Dynamics Toolkit.
@@ -35,7 +35,11 @@ const Float K  = 1.0;
 const Float ps = 1e-12;
 const Float fs = 1e-15;
 
-const Float Deg  = M_PI/180.0; 
+const Float Deg  = M_PI/180.0;
+
+const Vector3D NO_PBC = Vector3D(NO_PBC_L, NO_PBC_L, NO_PBC_L);
+
+//const int EL_ID_size = 200;
 
 }
 
