@@ -1,7 +1,7 @@
 /*
    The generalized manybody interatomic potential class.
 
-   Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009 Oleksandr
+   Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2012 Oleksandr
    Yermolenko <oleksandr.yermolenko@gmail.com>
 
    This file is part of MDTK, the Molecular Dynamics Toolkit.
@@ -28,26 +28,9 @@
 namespace mdtk
 {
 
-using std::fabs;
-using std::exp;
-using std::sqrt; 
-using std::pow; 
-
 FManybody::FManybody():
-  FGeneral(),pairs(),currentPairPtr(NULL)
+  FGeneral()
 {
 }
 
-void FManybody::onTouch(Atom& a)
-{
-    REQUIRE(a.globalIndex < pairs.size());
-    std::vector<AtomPair>& currentAtomPairs = pairs[a.globalIndex];
-    if (!std::binary_search(currentAtomPairs.begin(),currentAtomPairs.end(),*currentPairPtr))
-    {
-      REQUIRE((currentAtomPairs.size() == 0) || (*(currentAtomPairs.end()-1) < *currentPairPtr));
-      currentAtomPairs.push_back(*currentPairPtr);
-    }
-}  
-
 }
-
