@@ -2,7 +2,7 @@
    The Ziegler-Biersack-Littmark interatomic potential implementation
    (header file).
 
-   Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009 Oleksandr
+   Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2012 Oleksandr
    Yermolenko <oleksandr.yermolenko@gmail.com>
 
    This file is part of MDTK, the Molecular Dynamics Toolkit.
@@ -33,25 +33,22 @@ class FBZL : public FPairwise
 {
 private:
   Float AB_;
-public:  
-  Float F11(Atom& a1, Atom& a2);
-  Vector3D dF11(Atom& a1, Atom& a2, Atom& da);
 public:
-  virtual Float operator()(AtomsContainer&);
-  virtual Vector3D grad(Atom &a1,AtomsContainer&);
+  Float F11(AtomsPair& ij, const Float V = 0.0);
+public:
+  virtual Float operator()(AtomsArray&);
   FBZL(Rcutoff = Rcutoff());
 
   void SaveToStream(std::ostream& os, YAATK_FSTREAM_MODE smode)
   {
     FPairwise::SaveToStream(os,smode);
-  }  
+  }
   void LoadFromStream(std::istream& is, YAATK_FSTREAM_MODE smode)
   {
     FPairwise::LoadFromStream(is,smode);
-  }  
+  }
 };
 
-} 
+}
 
 #endif
-
